# FinanceLib

## Package Overview
  FinanceLib is easy-to-use Python library that has modules for representing the visualizations and analysis of commonly used finance related terms through graphs and charts.
  This 
  
## Table of Contents
 ### Usage
 This module can be used for the below given puposes:
 * Calculating the interest earned over the amount deposited.
 * Representation of change of Interest,Balance with respect to years through line or bar graphs.
 * Representation of ratios between Deposit and interest applied over it through pie chart.
 * Calculating and visvalisition of Relative stock index.
 * Measures and visualizes the Volatility of a Stock 
 ### Modules Included
   This Library mainly consists of three modules , namely :
   ### 1. interest:
   This module is further subdivided into two basic interests modules which are widely used and are the building blocks of any financial calculations.
   * **Simple_Interest() :**
   SI (Simple Interest) module can be used to get the graphs showing how much interest and deposit is growing  as well as the ratio of amount deposited and the interest earned over it in the given time period and rate of interest. This module can be used to:
   
   * **Compound_Interest():**
   CI (Compound Interest) module can be used to calculate interest on a loan or deposit based on both the initial principal and the accumulated interest from previous periods by taking principal amount, rate of interest(in %), time, compounding frequency as input. The output data is also represented through graph and pie chart.
   ### 2. genBanking:
   This module is further subdivided into two most commonly used finance terms namely,
   * **FD():**
   FD (Fixed Deposit) is the most widely used finance term with respect to investment.This is used to get the detailed information about the amount deposited,interest earned,maturity amount based on yearly,quaterly or monthly cummulative basis through bar graphs and pie chart.
   * **EMI():**
   EMI (Equated Monthly Interest) is the amount payable every month to the bank or any other financial institution until the loan amount is fully paid off. The calculated interest is shown via bar graph and pie chart to represent monthly interest and principal. Also monthly details are represented in a table as per the input (principal amount, rate of interest in percentage and tenure) given.
   ### 3. Analysis:
   This module is further subdivided into two very important stock analysis  fuctions which are widely used in financial risk management.
   * **rsi():**
   The relative strength index (RSI) is a momentum indicator used in technical analysis that measures the magnitude of recent price changes to evaluate overbought or oversold conditions in the price of a stock or other asset. 
   A technical indicator is a mathematical calculation based on past prices and volumes of a stock. The RSI has a value between 0 and 100. It is said to be overbought if above 70, and oversold if below 30.
   * **volatility():**
   Volatility is a statistical measure of the dispersion of returns for a given security or market index. In most cases, the higher the volatility, the riskier the security. Volatility is often measured as either the standard deviation or variance between returns from that same security or market index.
   Here we will calculate the same by using the ATR value.
   The average true range (ATR) is a market volatility indicator used in technical analysis.It is typically derived from the 14-day simple moving average of a series of true range indicators.

  ### Licence
  All the codes included in this packaging library is licensed under MIT License.
   
 
